function [xh,yh,uh,niter]=poisson(xspan,yspan,deltax,deltay,...
  ux1,ux2,uy1,uy2,f,tol);
  % Risolve l'equazione di Poisson
  % - Delta u = f
  % Descrivere i parametri formali
  % ux1: u(x1,y);
  % ux2: u(x2,y);
  %
  % The grid
  Nx=((xspan(2)-xspan(1))/deltax)+1;
  xh=linspace(xspan(1),xspan(2),Nx);
  Ny=((yspan(2)-yspan(1))/deltay)+1;
  yh=linspace(yspan(1),yspan(2),Ny);
  % Initialization of the approximate solution
  uh=zeros(Nx,Ny);
  % Initial conditions
  uh(1,:)=ux1(yh);
  uh(Nx,:)=ux2(yh);
  uh(:,1)=uy1(xh);
  uh(:,Ny)=uy2(xh);
  % Temporary storage area
  utemp=uh;
  % Initialization
  niter=0;
  itermax=Nx^2;
  maxdiff=tol+1.0;
  mux=deltay^2/(2*(deltax^2+deltay^2));
  muy=deltax^2/(2*(deltax^2+deltay^2));
  mu=(deltax*deltay)^2/(2*(deltax^2+deltay^2));
  while (maxdiff > tol && niter < itermax)
    niter=niter+1;
    for i=2:Nx-1
      for j=2:Ny-1
        utemp(i,j)=mux*(uh(i-1,j) + uh(i+1,j))...
        + muy*(uh(i,j-1) + uh(i,j+1)) + mu*f(xh(i),yh(j));
      end
    end
    maxdiff=max(max(abs(utemp - uh)));
    uh=utemp;
  end
end

