% This is a script for the integration of the
% Euler equation of motion of a free rigid body

% define the principal moments of inertia
global inertia=[2,2,8];

% define the time grid
t1=(0:0.1:3.14);

% define the equation of motion
re=@(ome_ang,t) rhs_euler_tot(ome_ang,t,inertia);

% Integration of the equation of motion
% CHANGE HERE THE INITIAL VALUES OF THE MOTION!
ome_ang1=lsode(re,[1,0,1,0,1,0],t1);

% Extract the components of the angular velocity and the Euler angles
o1=ome_ang1(:,1);
o2=ome_ang1(:,2);
o3=ome_ang1(:,3);
psi=ome_ang1(:,4);
theta=ome_ang1(:,5);
phi=ome_ang1(:,6);

% Initialize the moving frame
e1 = zeros(3,length(psi));
e2 = zeros(3,length(psi));
e3 = zeros(3,length(psi));

% Compute the comoving frame
for i = 1:length(psi)
    p = psi(i);
    t = theta(i);
    f = phi(i);
    rot = [cos(p)*cos(f)-sin(p)*cos(t)*sin(f)...
	   -sin(f)*cos(p)-cos(f)*sin(p)*cos(t)...
	   sin(t)*sin(p);
	   sin(p)*cos(f)+cos(p)*cos(t)*sin(f)...
	   -sin(f)*sin(p)+cos(f)*cos(p)*cos(t)...
	   -sin(t)*cos(p);
	   sin(t)*sin(f) cos(f)*sin(t) cos(t)];
    e1(:,i) = rot(:,1);
    e2(:,i) = rot(:,2);
    e3(:,i) = rot(:,3);
end

% Plot the comoving frame by plotting the vectors' tips on the unit sphere

% Initializes a figure
figure;
% Set the background color and the title on the window bar of the figure
set(gcf, 'color', 'w', 'name', 'Evolution of the comoving frame');

% Draw a transparent sphere
[X, Y, Z] = sphere;
sphere_pic = surf(X, Y, Z);
% Transparency is still not implemented in Octave!
set(sphere_pic, 'FaceAlpha', 0.1, 'EdgeAlpha', 1, 'LineWidth', 0.1);

% Title of the figure and labels
title({'Trajectories of the comoving frame on the unit sphere:';...
  'e_1 = blue, e_2 = red, e_3 = black'});
xlabel('\bfe\rm_1'); 
ylabel('\bfe\rm_2'); 
zlabel('\bfe\rm_3  ', 'rotation', 0);
axis equal;
hold on;

% Draw the initial position of the comoving frame
e1v = quiver3(0,0,0, e1(1,1), e1(2,1), e1(3,1), 'b', 'LineWidth', 2, 'AutoScale', 'off');
e2v = quiver3(0,0,0, e2(1,1), e2(2,1), e2(3,1), 'r', 'LineWidth', 2, 'AutoScale', 'off');
e3v = quiver3(0,0,0, e3(1,1), e3(2,1), e3(3,1), 'k', 'LineWidth', 2, 'AutoScale', 'off');

% Draw the trajectories of the tips of the comoving frame:
e1p = line(e1(1,:), e1(2,:), e1(3,:), 'Color', 'b', 'LineWidth', 1.5);
e2p = line(e2(1,:), e2(2,:), e2(3,:), 'Color', 'r', 'LineWidth', 1.5);
e3p = line(e3(1,:), e3(2,:), e3(3,:), 'Color', 'k', 'LineWidth', 1.5);
















